@@ -1367,6 +1367,7 @@ void init_form(void)
   /* Forms */
   rb_iv_set(mForm, "@forms_hash", rb_hash_new());
   cFORM  = rb_define_class_under(mForm, "FORM", rb_cObject);
+  rb_undef_alloc_func(cFORM);
   rb_define_singleton_method(cFORM, "new",
 									  (&rbncurs_m_new_form),
 									  1);
@@ -1413,22 +1414,23 @@ void init_form(void)
   /* Fields */
   rb_iv_set(mForm, "@fields_hash", rb_hash_new());
   cFIELD = rb_define_class_under(mForm, "FIELD", rb_cObject);
+  rb_undef_alloc_func(cFIELD);
   rb_define_singleton_method(cFIELD, "new",
 									  (&rbncurs_m_new_field),
 									  6);
   RB_CLASS_METH(cFIELD, "dup", dup_field,2);
   RB_CLASS_METH(cFIELD, "dynamic_info", dynamic_field_info,3);
   RB_CLASS_METH(cFIELD, "arg", field_arg,0);
-  RB_CLASS_METH(cFIELD, "back", field_back,1);
+  RB_CLASS_METH(cFIELD, "back", field_back,0);
   RB_CLASS_METH(cFIELD, "buffer", field_buffer,1);
-  RB_CLASS_METH(cFIELD, "fore", field_fore,1);
+  RB_CLASS_METH(cFIELD, "fore", field_fore,0);
   RB_CLASS_METH(cFIELD, "index", field_index,0);
   RB_CLASS_METH(cFIELD, "info", field_info,6);
   RB_CLASS_METH(cFIELD, "just", field_just,0);
   RB_CLASS_METH(cFIELD, "opts", field_opts,0);
   RB_CLASS_METH(cFIELD, "opts_off", field_opts_off,1);
   RB_CLASS_METH(cFIELD, "opts_on", field_opts_on,1);
-  RB_CLASS_METH(cFIELD, "pad", field_pad,1);
+  RB_CLASS_METH(cFIELD, "pad", field_pad,0);
   RB_CLASS_METH(cFIELD, "status", field_status,0);
   RB_CLASS_METH(cFIELD, "type", field_type,0);
   /*   RB_CLASS_METH(cFIELD, "userptr", field_userptr,0); */
@@ -1454,6 +1456,7 @@ void init_form(void)
   /* Field types */
   rb_iv_set(mForm, "@fieldtypes_hash", rb_hash_new());
   cFIELDTYPE = rb_define_class_under(mForm, "FIELDTYPE", rb_cObject);
+  rb_undef_alloc_func(cFIELDTYPE);
   rb_define_singleton_method(cFIELDTYPE, "new",
 									  (&rbncurs_m_new_fieldtype),
 									  2);
